@@ -167,7 +167,7 @@ Net::Google::DataAPI::Role::Entry provides base functionalities for the entry of
 
 =head1 AUTHOR
 
-Nobuo Danjou E<lt>nobuo.danjou@gmail.comE<gt>
+Nobuo Danjou E<lt>danjou@soffritto.orgE<gt>
 
 =head1 SEE ALSO
 
